#!/bin/bash

# Update CSPP applications to handle 01/01/2017 leap second insertion
# Liam.Gumley@ssec.wisc.edu Dec 12, 2016

# Check arguments
if [ $# -ne 1 ]; then
  echo "Usage: cspp_leapsec_update_2016.bash path"
  echo "where"
  echo "path is the name of the directory path to search"
  exit 1
fi

# Get arguments
path=$1

# Update IETTime.dat and nagg
filenames="IETTime.dat nagg"
for file in $filenames; do
  list=$(find $path -name $file)
  if [ -z "$list" ]; then echo "No instances of "$file" were found to update"; fi
  for item in $list; do
    echo
    sig1=$(md5sum $file | cut -d" " -f1)
    sig2=$(md5sum $item | cut -d" " -f1)
    if [ "$sig1" != "$sig2" ]; then
      read -p "Do you wish to update "$item" ? [y/n]: " answer
      if [ "$answer" == "y" ]; then
        rsync -aq $file $(dirname $item)
        if [ $? -eq 0 ]; then echo "Update successful"; fi
      fi
    else
      echo $item" is up to date"
    fi
  done
done

# Update MIRS rdr2tdr_npp_atms and ACSPO leapsec.dat
filenames="mirs_v11r1_r3636/bin/rdr2tdr_npp_atms ACSPO_V2-40_CSPP_20151120/run/static_anc/modis/leapsec.dat"
for file in $filenames; do
  dir=$(echo $file | cut -d'/' -f1)
  name=$(find $path -type d -name $dir)
  if [ -n "$name" ]; then
    echo
    item=$name/$(echo $file | cut -d"/" -f2-)
    sig1=$(md5sum $(basename $file) | cut -d" " -f1)
    sig2=$(md5sum $item | cut -d" " -f1)
    if [ "$sig1" != "$sig2" ]; then
      read -p "Do you wish to update "$item" ? [y/n]: " answer
      if [ "$answer" == "y" ]; then
        rsync -aq $(basename $file) $(dirname $item)
        if [ $? -eq 0 ]; then echo "Update successful"; fi
      fi
    else
      echo $item" is up to date"
    fi
  else
    echo "Directory "$dir" was not found"
  fi
done

exit 0

